# Contributing to Devise Materialize

First and for most thank you for taking the time to look to contribute to
Devise Materialize, any help is apprciated to make Devise Materialize better
and stronger!

## Table of Contents

- [Code of Conduct](#code-of-conduct)
- [How can I Contribute](#how-can-i-contribute)
  - [Reporting Bugs](#reporting-bugs)
  - [Suggesting Enhancements](#suggesting-enhancements)
- [Code Contributions](#code-contributions)
- [Pull Requests](#pull-requests)
- [Additional Notes](#additional-notes)
  - [Issue and Pull Request Labels](#issue-and-pull-request-labels)

## Code of Conduct

This project and everyone participating in it is governed by the [Simplecov
Material Code of Conduct](https://github.com/chiefpansancolt/devise_materialize/blob/master/CODE_OF_CONDUCT.md).
By participating, you are expected to uphold this code. Please report
unacceptable behavior to chiefpansancolt@gmail.com.

## How can I Contribute

### Reporting Bugs

#### Before submitting a bug report

This section guides you through submitting a bug report for Devise Materialize.
Following these guidelines helps maintainers and the community understand your
report 📝, reproduce the behavior 💻 💻, and find related reports 🔎.

Before creating bug reports, please check [this list](https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Abug)
as you might find out that you don't need to create one. When you are creating
a bug report, please include as many details as possible. Fill out the
[required template](https://github.com/chiefpansancolt/devise_materialize/blob/master/.github/ISSUE_TEMPLATE/bug_report.md)
, the information it asks for helps us resolve issues faster.

> Note: If you find a Closed issue that seems like it is the same thing that you're experiencing, open a new issue and include a link to the original issue in the body of your new one.

## Suggesting Enhancements

This section guides you through submitting an enhancement suggestion for
Devise Materialize, including completely new features and minor improvements to
existing functionality. Following these guidelines helps maintainers and the
community understand your suggestion 📝 and find related suggestions 🔎.

Before creating enhancement suggestions, please check [this list](https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Aenhancement)
as you might find out that you don't need to create one. When you are creating
an enhancement suggestion, please include as many details as possible. Fill in
the [template](https://github.com/chiefpansancolt/devise_materialize/blob/master/.github/ISSUE_TEMPLATE/feature-request.md)
, including the steps that you imagine you would take if the feature you're
requesting existed.

## Code Contributions

Looking to contribute to Simplecov? You can look for any tickets tagged with `help-wanted`

- [Help wanted issues](https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A%22help+wanted%22) - issues which could use help form the community to help complete

## Pull Requests

The process described here has several goals:

- Maintain Devise Materialize's quality
- Fix problems that are important to users
- Engage the community in working toward the best possible Devise Materialize Interaction
- Enable a sustainable system for Devise Materialize's maintainers to review contributions

Please follow these steps to have your contribution considered by the maintainers:

- Follow all instructions in [the template](https://github.com/chiefpansancolt/devise_materialize/blob/master/.github/PULL_REQUEST_TEMPLATE.md)
- After you submit your pull request, verify that all status checks are passing<details><summary>What if the status checks are failing?</summary>If a status check is failing, and you believe that the failure is unrelated to your change, please leave a comment on the pull request explaining why you believe the failure is unrelated. A maintainer will re-run the status check for you. If we conclude that the failure was a false positive, then we will open an issue to track that problem with our status check suite.</details>

While the prerequisites above must be satisfied prior to having your pull request reviewed, the reviewer(s) may ask you to complete additional design work, tests, or other changes before your pull request can be ultimately accepted.

## Additional Notes

### Issue and Pull Request Labels

This section lists the labels we use to help us track and manage issues and pull requests.

[GitHub search](https://help.github.com/articles/searching-issues/) makes it easy to use labels for finding groups of issues or pull requests you're interested in. For example, you might be interested in opening an Issue or perhaps opening a pull request. To help you find issues and pull requests, each label is listed with search links for finding open items with that label in Devise Materialize. We  encourage you to read about [other search filters](https://help.github.com/articles/searching-issues/) which will help you write more focused queries.

#### Type of Issue and Issue State

| Label Name | Repo |  Description |
| --- | --- | --- |
| `enhancement` | [search][search-devise-materialize-label-enhancement] | Feature requests. |
| `bug` | [search][search-devise-materialize-label-bug] | Confirmed bugs or reports that are very likely to be bugs. |
| `question` | [search][search-devise-materialize-label-question] | Questions more than bug reports or feature requests (e.g. how do I do X). |
| `feedback` | [search][search-devise-materialize-label-feedback] | General feedback more than bug reports or feature requests. |
| `help-wanted` | [search][search-devise-materialize-label-help-wanted] | The Devise Materialize team would appreciate help from the community in resolving these issues. |
| `more-information-needed` | [search][search-devise-materialize-label-more-information-needed] | More information needs to be collected about these problems or feature requests (e.g. steps to reproduce). |
| `needs-reproduction` | [search][search-devise-materialize-label-needs-reproduction] | Likely bugs, but haven't been reliably reproduced. |
| `blocked` | [search][search-devise-materialize-label-blocked] | Issues blocked on other issues. |
| `duplicate` | [search][search-devise-materialize-label-duplicate] | Issues which are duplicates of other issues, i.e. they have been reported before. |
| `wontfix` | [search][search-devise-materialize-label-wontfix] | The Devise Materialize team has decided not to fix these issues for now, either because they're working as intended or for some other reason. |
| `invalid` | [search][search-devise-materialize-label-invalid] | Issues which aren't valid (e.g. user errors). |
| `new` | [search][search-devise-materialize-label-new] | Tagged on Issues that are new and have not been reviewed. |
| `tech debt` | [search][search-devise-materialize-label-tech-debt] | Items to clean up / refactor / restructure |

#### Pull Request Labels

| Label Name | Repo | Description
| --- | --- | --- |
| `work-in-progress` | [search][search-devise-materialize-label-work-in-progress] | Pull Requests which are still being worked on, more changes will follow. |
| `needs-review` | [search][search-devise-materialize-label-needs-review] | Pull Requests which need code review, and approval from maintainers. |
| `under-review` | [search][search-devise-materialize-label-under-review] | Pull Requests being reviewed by maintainers. |
| `requires-changes` | [search][search-devise-materialize-label-requires-changes] | Pull Requests which need to be updated based on review comments and then reviewed again. |
| `needs-testing` | [search][search-devise-materialize-label-needs-testing] | Pull Requests which need manual testing. |

[search-devise-materialize-label-enhancement]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Aenhancement
[search-devise-materialize-label-bug]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Abug
[search-devise-materialize-label-question]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Aquestion
[search-devise-materialize-label-feedback]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Afeedback
[search-devise-materialize-label-help-wanted]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A%22help+wanted%22
[search-devise-materialize-label-more-information-needed]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A%22more+information+needed%22
[search-devise-materialize-label-needs-reproduction]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A%22needs+reproduction%22
[search-devise-materialize-label-blocked]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Ablocked
[search-devise-materialize-label-duplicate]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Aduplicate
[search-devise-materialize-label-wontfix]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Awontfix
[search-devise-materialize-label-invalid]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Ainvalid
[search-devise-materialize-label-new]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3Anew
[search-devise-materialize-label-tech-debt]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"tech+debt"
[search-devise-materialize-label-work-in-progress]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"work+in+progress"
[search-devise-materialize-label-needs-review]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"needs+review"
[search-devise-materialize-label-under-review]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"under+review"
[search-devise-materialize-label-requires-changes]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"requires+changes"
[search-devise-materialize-label-needs-testing]: https://github.com/chiefpansancolt/devise_materialize/issues?q=is%3Aopen+is%3Aissue+label%3A"needs+testing"
